@@ -20,7 +20,7 @@ def validate_status_code(status_code: int) -> Union[
     elif status_code in range(status.HTTP_405_METHOD_NOT_ALLOWED, status.HTTP_417_EXPECTATION_FAILED + 1):
         exception_class = APIError(str(status_code))
     elif status.is_server_error(status_code):
-        exception_class = ServerError(str(status_code))
+        exception_class = ServerError(str(status_code), {'errorMessage': 'API experiencing difficulties. Try later.'})
 
     if exception_class:
         return False, exception_class
